@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2013 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_RESULT_H
@@ -10,7 +10,7 @@
 /*
  * Types
  */
- 
+
 struct sieve_side_effects_list;
 
 /*
@@ -20,13 +20,13 @@ struct sieve_side_effects_list;
 struct sieve_result;
 
 struct sieve_result *sieve_result_create
-	(struct sieve_instance *svinst, const struct sieve_message_data *msgdata, 
+	(struct sieve_instance *svinst, const struct sieve_message_data *msgdata,
 		const struct sieve_script_env *senv,
 		struct sieve_error_handler *ehandler);
 
-void sieve_result_ref(struct sieve_result *result); 
+void sieve_result_ref(struct sieve_result *result);
 
-void sieve_result_unref(struct sieve_result **result); 
+void sieve_result_unref(struct sieve_result **result);
 
 pool_t sieve_result_pool(struct sieve_result *result);
 
@@ -54,10 +54,10 @@ void sieve_result_extension_set_context
 	(struct sieve_result *result, const struct sieve_extension *ext,
 		void *context);
 const void *sieve_result_extension_get_context
-	(struct sieve_result *result, const struct sieve_extension *ext); 
+	(struct sieve_result *result, const struct sieve_extension *ext);
 
-/* 
- * Result printing 
+/*
+ * Result printing
  */
 
 struct sieve_result_print_env {
@@ -67,7 +67,8 @@ struct sieve_result_print_env {
 };
 
 void sieve_result_vprintf
-	(const struct sieve_result_print_env *penv, const char *fmt, va_list args);
+	(const struct sieve_result_print_env *penv, const char *fmt, va_list args)
+		ATTR_FORMAT(2, 0);
 void sieve_result_printf
 	(const struct sieve_result_print_env *penv, const char *fmt, ...)
 		ATTR_FORMAT(2, 3);
@@ -79,11 +80,11 @@ void sieve_result_seffect_printf
 		ATTR_FORMAT(2, 3);
 
 bool sieve_result_print
-	(struct sieve_result *result, const struct sieve_script_env *senv, 
+	(struct sieve_result *result, const struct sieve_script_env *senv,
 		struct ostream *stream, bool *keep);
 
-/* 
- * Error handling 
+/*
+ * Error handling
  */
 
 void sieve_result_error
@@ -102,6 +103,12 @@ void sieve_result_log
 (const struct sieve_action_exec_env *aenv, const char *fmt, ...)
 	ATTR_FORMAT(2, 3);
 void sieve_result_global_log
+(const struct sieve_action_exec_env *aenv, const char *fmt, ...)
+	ATTR_FORMAT(2, 3);
+void sieve_result_global_log_error
+(const struct sieve_action_exec_env *aenv, const char *fmt, ...)
+	ATTR_FORMAT(2, 3);
+void sieve_result_global_log_warning
 (const struct sieve_action_exec_env *aenv, const char *fmt, ...)
 	ATTR_FORMAT(2, 3);
 
@@ -133,7 +140,7 @@ void sieve_result_set_failure_action
 /*
  * Result execution
  */
- 
+
 bool sieve_result_implicit_keep(struct sieve_result *result);
 
 void sieve_result_mark_executed(struct sieve_result *result);
@@ -152,15 +159,15 @@ const struct sieve_action *sieve_result_iterate_next
 	(struct sieve_result_iterate_context *rictx, bool *keep);
 void sieve_result_iterate_delete
 	(struct sieve_result_iterate_context *rictx);
-	
+
 /*
  * Side effects list
  */
- 
+
 struct sieve_side_effects_list *sieve_side_effects_list_create
 	(struct sieve_result *result);
 void sieve_side_effects_list_add
-	(struct sieve_side_effects_list *list, 
+	(struct sieve_side_effects_list *list,
 		const struct sieve_side_effect *seffect);
 
 #endif
